# RKE Resource Provider

The RKE resource provider for Pulumi lets you create a Kubernetes cluster using RKE in your cloud programs. To use
this package, please [install the Pulumi CLI first](https://pulumi.io/).

## Installing

This package is available in many languages in the standard packaging formats.

### Node.js (Java/TypeScript)

To use from JavaScript or TypeScript in Node.js, install using either `npm`:

```
$ npm install @jaxxstorm/pulumi-rke
```

or `yarn`:

```
$ yarn add @jaxxstorm/pulumi-rke
```

### Python

To use from Python, install using `pip`:

```
$ pip install pulumi_rke
```

### Go

To use from Go, use `go get` to grab the latest version of the library

```
$ go get github.com/jaxxstorm/pulumi-rke/sdk/go/...
```

### .NET

To use from Dotnet, use `dotnet add package` to install into your project. You must specify the version if it is a pre-release version.

```
$ dotnet add package Pulumi.Rke --version 0.2.0-preview
```

## Reference

Coming Soon
